==> zeebe-gateway-1.3.6-sources.jar: io/camunda/zeebe/gateway/impl/probes/liveness/LivenessResponsiveHealthIndicatorAutoConfiguration.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH under
 * one or more contributor license agreements. See the NOTICE file distributed
 * with this work for additional information regarding copyright ownership.
 * Licensed under the Zeebe Community License 1.1. You may not use this file
 * except in compliance with the Zeebe Community License 1.1.
 */
package io.camunda.zeebe.gateway.impl.probes.liveness;

import io.camunda.zeebe.gateway.impl.configuration.GatewayCfg;
import io.camunda.zeebe.gateway.impl.probes.health.ResponsiveHealthIndicator;
import io.camunda.zeebe.util.health.DelayedHealthIndicator;
import io.camunda.zeebe.util.health.MemoryHealthIndicator;
import org.springframework.boot.actuate.autoconfigure.health.ConditionalOnEnabledHealthIndicator;
import org.springframework.boot.actuate.autoconfigure.health.HealthContributorAutoConfiguration;
import org.springframework.boot.actuate.health.HealthIndicator;
import org.springframework.boot.autoconfigure.AutoConfigureBefore;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;

/** {@link EnableAutoConfiguration Auto-configuration} for {@link MemoryHealthIndicator}. */
@Configuration(proxyBeanMethods = false)
@ConditionalOnEnabledHealthIndicator("gateway-responsive")
@AutoConfigureBefore(HealthContributorAutoConfiguration.class)
@EnableConfigurationProperties(LivenessResponsiveHealthIndicatorProperties.class)
@EnableScheduling
public class LivenessResponsiveHealthIndicatorAutoConfiguration {

  @Bean
  @ConditionalOnMissingBean(name = "livenessGatewayResponsiveHealthIndicator")
  public HealthIndicator livenessGatewayResponsiveHealthIndicator(
      GatewayCfg gatewayCfg, LivenessResponsiveHealthIndicatorProperties properties) {
    return new DelayedHealthIndicator(
        gatewayResponsiveHealthIndicator(gatewayCfg, properties), properties.getMaxDowntime());
  }

  private ResponsiveHealthIndicator gatewayResponsiveHealthIndicator(
      GatewayCfg gatewayCfg, LivenessResponsiveHealthIndicatorProperties properties) {
    return new ResponsiveHealthIndicator(gatewayCfg, properties.getRequestTimeout());
  }
}

==> zeebe-gateway-8.2.2-sources.jar: io/camunda/zeebe/gateway/impl/probes/liveness/LivenessResponsiveHealthIndicatorAutoConfiguration.java <==
/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH under
 * one or more contributor license agreements. See the NOTICE file distributed
 * with this work for additional information regarding copyright ownership.
 * Licensed under the Zeebe Community License 1.1. You may not use this file
 * except in compliance with the Zeebe Community License 1.1.
 */
package io.camunda.zeebe.gateway.impl.probes.liveness;

import io.camunda.zeebe.gateway.impl.configuration.GatewayCfg;
import io.camunda.zeebe.gateway.impl.probes.health.ResponsiveHealthIndicator;
import io.camunda.zeebe.util.health.DelayedHealthIndicator;
import io.camunda.zeebe.util.health.MemoryHealthIndicator;
import org.springframework.boot.actuate.autoconfigure.health.ConditionalOnEnabledHealthIndicator;
import org.springframework.boot.actuate.autoconfigure.health.HealthContributorAutoConfiguration;
import org.springframework.boot.actuate.health.HealthIndicator;
import org.springframework.boot.autoconfigure.AutoConfigureBefore;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;

/** {@link EnableAutoConfiguration Auto-configuration} for {@link MemoryHealthIndicator}. */
@Configuration(proxyBeanMethods = false)
@ConditionalOnEnabledHealthIndicator("gateway-responsive")
@AutoConfigureBefore(HealthContributorAutoConfiguration.class)
@EnableConfigurationProperties(LivenessResponsiveHealthIndicatorProperties.class)
@EnableScheduling
public class LivenessResponsiveHealthIndicatorAutoConfiguration {

  @Bean
  @ConditionalOnMissingBean(name = "livenessGatewayResponsiveHealthIndicator")
  public HealthIndicator livenessGatewayResponsiveHealthIndicator(
      final GatewayCfg gatewayCfg, final LivenessResponsiveHealthIndicatorProperties properties) {
    return new DelayedHealthIndicator(
        gatewayResponsiveHealthIndicator(gatewayCfg, properties), properties.getMaxDowntime());
  }

  private ResponsiveHealthIndicator gatewayResponsiveHealthIndicator(
      final GatewayCfg gatewayCfg, final LivenessResponsiveHealthIndicatorProperties properties) {
    return new ResponsiveHealthIndicator(gatewayCfg, properties.getHealthZeebeClientProperties());
  }
}
